geowatch.tasks.poly\_from\_point.predict module
===============================================

.. automodule:: geowatch.tasks.poly_from_point.predict
   :members:
   :undoc-members:
   :show-inheritance:
